---
title: <span class="badge object-type-scalar"></span> TebibytesPerSecond
---
# <span class="badge object-type-scalar"></span> TebibytesPerSecond

Data rate: tebibytes/sec

## Definition

```python
# Data rate: tebibytes/sec
TebibytesPerSecond: typing.Literal["TiBs"] = "TiBs"
```
